summaryrefslogtreecommitdiff
path: root/sys/dev/ic/lance.c
diff options
context:
space:
mode:
authorthorpej <thorpej@NetBSD.org>2001-07-07 15:59:37 +0000
committerthorpej <thorpej@NetBSD.org>2001-07-07 15:59:37 +0000
commit150ca9d41a3b0f752a2a98f421bd41d41da0eb3d (patch)
tree46ea63669b948f68d769bb805d8301831b1f57dd /sys/dev/ic/lance.c
parent7e84e14950d2854a2b7edba8f61a67f3ad11bab8 (diff)
bcopy -> memcpy, strcpy
Diffstat (limited to 'sys/dev/ic/lance.c')
-rw-r--r--sys/dev/ic/lance.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/sys/dev/ic/lance.c b/sys/dev/ic/lance.c
index a18d4192032..b6166965437 100644
--- a/sys/dev/ic/lance.c
+++ b/sys/dev/ic/lance.c
@@ -1,4 +1,4 @@
-/* $NetBSD: lance.c,v 1.23 2001/07/07 05:35:40 thorpej Exp $ */
+/* $NetBSD: lance.c,v 1.24 2001/07/07 15:59:37 thorpej Exp $ */
/*-
* Copyright (c) 1997, 1998 The NetBSD Foundation, Inc.
@@ -197,7 +197,7 @@ lance_config(sc)
struct ifnet *ifp = &sc->sc_ethercom.ec_if;
/* Initialize ifnet structure. */
- bcopy(sc->sc_dev.dv_xname, ifp->if_xname, IFNAMSIZ);
+ strcpy(ifp->if_xname, sc->sc_dev.dv_xname);
ifp->if_softc = sc;
ifp->if_start = sc->sc_start;
ifp->if_ioctl = lance_ioctl;
@@ -712,9 +712,9 @@ lance_copytobuf_contig(sc, from, boff, len)
volatile caddr_t buf = sc->sc_mem;
/*
* Just call bcopy() to do the work.
*/
- bcopy(from, buf + boff, len);
+ memcpy(buf + boff, from, len);
}
void
@@ -726,9 +726,9 @@ lance_copyfrombuf_contig(sc, to, boff, len)
volatile caddr_t buf = sc->sc_mem;
/*
* Just call bcopy() to do the work.
*/
- bcopy(buf + boff, to, len);
+ memcpy(to, buf + boff, len);
}
void
@@ -860,7 +860,7 @@ lance_copytobuf_gap16(sc, fromv, boff, len)
boff &= 0xf;
xfer = min(len, 16 - boff);
while (len > 0) {
- bcopy(from, bptr + boff, xfer);
+ memcpy(bptr + boff, from, xfer);
from += xfer;
bptr += 32;
boff = 0;
@@ -884,7 +884,7 @@ lance_copyfrombuf_gap16(sc, tov, boff, len)
boff &= 0xf;
xfer = min(len, 16 - boff);
while (len > 0) {
- bcopy(bptr + boff, to, xfer);
+ memcpy(to, bptr + boff, xfer);
to += xfer;
bptr += 32;
boff = 0;
@@ -712,9 +712,9 @@ lance_copytobuf_contig(sc, from, boff, len)
volatile caddr_t buf = sc->sc_mem;
/*
- * Just call bcopy() to do the work.
+ * Just call memcpy() to do the work.
*/
@@ -726,9 +726,9 @@ lance_copyfrombuf_contig(sc, to, boff, len)
volatile caddr_t buf = sc->sc_mem;
/*
- * Just call bcopy() to do the work.
+ * Just call memcpy() to do the work.
*/